@@ -17,7 +17,7 @@ use vars qw($VERSION $AUTOLOAD);
 use Image::ExifTool qw(:DataAccess :Utils);
 require Exporter;
 
-$VERSION = '1.16';
+$VERSION = '1.18';
 
 sub FetchObject($$$$);
 sub ExtractObject($$;$$);
@@ -88,7 +88,7 @@ my $pdfVer;         # version of PDF file being processed
         PrintConvInv => '$self->InverseDateTime($val)', 
     },
     Trapped => {
-        Writable => 0,
+        Protected => 1,
         # remove leading '/' from '/True' or '/False'
         ValueConv => '$val=~s{^/}{}; $val',
         ValueConvInv => '"/$val"',
@@ -358,7 +358,8 @@ sub LocateAnyObject($$)
                 my $w = $$dict{W};
                 for ($j=0; $j<3; ++$j) {
                     # use default value if W entry is 0 (as per spec)
-                    $$w[$j] or $t[$j] = ($j ? 1 : 0), next;
+                    # - 0th element defaults to 1, others default to 0
+                    $$w[$j] or $t[$j] = ($j ? 0 : 1), next;
                     $t[$j] = shift(@c);
                     for ($k=1; $k < $$w[$j]; ++$k) {
                         $t[$j] = 256 * $t[$j] + shift(@c);
@@ -444,7 +445,7 @@ sub FetchObject($$$$)
             return undef unless @table == $num;
             # remove everything before first object in stream
             $$obj{_stream} = substr($$obj{_stream}, $$obj{First});
-            $table[$num-1] =~ s/^(\d+).*/$1/;  # trim excess from last number
+            $table[$num-1] =~ s/^(\d+).*/$1/s;  # trim excess from last number
             $$obj{_table} = \@table;
             # save the object stream so we don't have to re-load it later
             $streamObjs{$ref} = $obj;
@@ -586,7 +587,7 @@ sub ExtractObject($$;$$)
 # extract array
 #
     } elsif ($delim eq '[') {
-        $objData =~ /.*?\[(.*)\]/s or return;
+        $objData =~ /.*?\[(.*)\]/s or return undef;
         my $data = $1;    # brackets removed
         my @list;
         for (;;) {
@@ -1056,7 +1057,10 @@ sub ProcessDict($$$$;$$)
                 } else {
                     $fetched{$$val} = 1;
                     $val = FetchObject($exifTool, $$val, $xref, $tag);
-                    $val2 = '<err>' unless defined $val;
+                    unless (defined $val) {
+                        $val2 = '<err>';
+                        $exifTool->VPrint(0, "$$exifTool{INDENT}Error reading object:\n");
+                    }
                 }
             } elsif (ref $val eq 'HASH') {
                 $extra = ', direct dictionary';
@@ -1154,8 +1158,9 @@ sub ProcessDict($$$$;$$)
                 next if $fetched{$$subDict};
                 # load dictionary via an indirect reference
                 $fetched{$$subDict} = 1;
-                $subDict = FetchObject($exifTool, $$subDict, $xref, $tag);
-                $subDict or $exifTool->Warn("Error reading $tag object"), next;
+                my $obj = FetchObject($exifTool, $$subDict, $xref, $tag);
+                $obj or $exifTool->Warn("Error reading $tag object ($$subDict)"), next;
+                $subDict = $obj;
             }
             if (ref $subDict eq 'ARRAY') {
                 # convert array of key/value pairs to a hash
@@ -1252,7 +1257,7 @@ sub ReadPDF($$)
     $raf->Seek(-$len, 2) or return -2;
     $raf->Read($buff, $len) == $len or return -3;
     # find the last xref table in the file (may be multiple %%EOF marks)
-    $buff =~ /.*startxref(\x0d\x0a|\x0a\x0a|\x0d|\x0a)(\d+)\1%%EOF/s or return -4;
+    $buff =~ /.*startxref *(\x0d\x0a|\x0d|\x0a)\s*?(\d+)\s+%%EOF/s or return -4;
     $/ = $1;    # set input record separator
     push @xrefOffsets, $2, 'Main';
     my (%xref, @mainDicts, %loaded, $mainFree);
